.. pyclesperanto documentation master file, created by
   sphinx-quickstart on Wed Mar 22 13:58:38 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

******************************************************
py-clesperanto documentation
******************************************************

py-clesperanto is the python package of clEsperanto - a multi-language framework for GPU-accelerated image processing.
You will find here a first draft of the API for reference and documentation purposes as well as how to use the package.

.. note::

   This project is under active development, as well as its documentation.


.. toctree::
    install
    usage
    api
    genindex



